@@ -417,8 +417,9 @@ sub oddmuse_gemini_text {
   $text =~ s/^(```.*?\n```)\n/push(@escaped, $1); "\x03" . $ref++ . "\x04\n"/mesg;
   $text =~ s/^<pre>\n?(.*?\n)<\/pre>\n?/push(@escaped, "```\n$1```\n"); "\x03" . $ref++ . "\x04\n"/mesg;
   $text =~ s/^((\|.*\|\n)*\|.*\|)/push(@escaped, "```\n$1\n```"); "\x03" . $ref++ . "\x04\n"/meg;
-  my @blocks = split(/\n\n+|(?=\\\\\n)|\n(?=\*|=>)|\n\> *\n/, $text);
+  my @blocks = split(/\n\n+|(?=\\\\\n)|\n(?=[*-]|=>)|\n\> *\n/, $text);
   for my $block (@blocks) {
+    $block =~ s/^- /* /g; # fix list items
     $block =~ s/\s+/ /g; # unwrap lines
     $block =~ s/^\s+//; # trim
     $block =~ s/\s+$//; # trim
@@ -469,6 +470,7 @@ sub oddmuse_gemini_text {
   $text =~ s/\n\\\\ //g; # remove paragraph separation for linebreaks
   $text =~ s/^\* (.*)\n(=> \S+ \1)/$2/mg; # remove list items that are just links
   $text =~ s/^(=?>.*\n)\n(?==>)/$1/mg; # remove empty lines between links or between links and quotes
+  $text =~ s/^(\* .*\n)\n(?=\* )/$1/mg; # remove empty lines between list items
   $text =~ s/^Tags: .*/Tags:/m;
   $text =~ s/\x03(\d+)\x04/$escaped[$1]/ge;
   return $text . "\n";
@@ -656,6 +658,41 @@ sub oddmuse_serve_index {
   }
 }
 
+sub oddmuse_serve_match {
+  my $stream = shift;
+  my $host = shift;
+  my $space = shift;
+  my $term = shift;
+  $log->info("Serving pages matching $term");
+  success($stream);
+  $stream->write(encode_utf8 "# Pages matching ‘$term’\n");
+  # we need to call our own: if we import pages from App:Phoebe, we get a copy
+  # and would have to remap that just like we do App::Phoebe::pages below
+  my @pages = oddmuse_pages_new($stream, $host, $space, $term);
+  for my $id (@pages) {
+    print_link($stream, $host, $space, normal_to_free($id), "page/$id");
+  }
+}
+
+sub oddmuse_serve_search {
+  my $stream = shift;
+  my $host = shift;
+  my $space = shift;
+  my $term = shift;
+  $log->info("Serving search for $term");
+  success($stream);
+  $stream->write(encode_utf8 "# Search ‘$term’\n");
+  my $url = "$oddmuse_wikis{$host}?raw=1&search=" . uri_escape_utf8($term);
+  my $page = oddmuse_get_raw($stream, $url) // return;
+  my @entries = split(/\n\n+/, $page);
+  shift @entries; # skip head
+  foreach my $entry (@entries) {
+    my $data = parse_data($entry);
+    my $id = $data->{title};
+    print_link($stream, $host, $space, normal_to_free($id), "page/$id");
+  }
+}
+
 # this is required when combining gopher with oddmuse!
 *oddmuse_pages_old = \&App::Phoebe::pages;
 *App::Phoebe::pages = \&oddmuse_pages_new;
@@ -668,7 +705,7 @@ sub oddmuse_pages_new {
   if (exists $oddmuse_wikis{$host}) {
     my $url = "$oddmuse_wikis{$host}?raw=1;action=index";
     $url .= ";ns=$space" if $space;
-    $url .= ";match=" . uri_escape($re) if $re;
+    $url .= ";match=" . uri_escape_utf8($re) if $re;
     return map { s/_/ /g; $_ } split(/\n/, oddmuse_get_raw($stream, $url));
   }
   return oddmuse_pages_old($stream, $host, $space, $re);
@@ -843,40 +880,6 @@ sub oddmuse_serve_diff {
   }
 }
 
-sub oddmuse_serve_match {
-  my $stream = shift;
-  my $host = shift;
-  my $space = shift;
-  my $term = shift;
-  $log->info("Serving pages matching $term");
-  success($stream);
-  $stream->write(encode_utf8 "# Pages matching ‘$term’\n");
-  my $url = "$oddmuse_wikis{$host}?raw=1;action=index;match=" . uri_escape_utf8($term);
-  my @pages = split(/\n/, oddmuse_get_raw($stream, $url)) // return;
-  for my $id (@pages) {
-    print_link($stream, $host, $space, normal_to_free($id), "page/$id");
-  }
-}
-
-sub oddmuse_serve_search {
-  my $stream = shift;
-  my $host = shift;
-  my $space = shift;
-  my $term = shift;
-  $log->info("Serving search for $term");
-  success($stream);
-  $stream->write(encode_utf8 "# Search ‘$term’\n");
-  my $url = "$oddmuse_wikis{$host}?raw=1&search=" . uri_escape_utf8($term);
-  my $page = oddmuse_get_raw($stream, $url) // return;
-  my @entries = split(/\n\n+/, $page);
-  shift @entries; # skip head
-  foreach my $entry (@entries) {
-    my $data = parse_data($entry);
-    my $id = $data->{title};
-    print_link($stream, $host, $space, normal_to_free($id), "page/$id");
-  }
-}
-
 sub oddmuse_serve_rss {
   my $stream = shift;
   my $host = shift;
